@@ -3,7 +3,7 @@ use warnings;
 
 package Net::Amazon::Route53::Change;
 BEGIN {
-  $Net::Amazon::Route53::Change::VERSION = '0.110310';
+  $Net::Amazon::Route53::Change::VERSION = '0.111300';
 }
 use Mouse;
 use HTML::Entities;
@@ -65,7 +65,9 @@ sub refresh {
     my $self = shift;
     die "Cannot refresh without an id\n" unless length $self->id;
     my $resp =
-      $self->route53->request( 'get', 'https://route53.amazonaws.com/2010-10-01/' . $self->id, );
+      $self->route53->request( 'get',
+        'https://route53.amazonaws.com/2010-10-01/' . $self->id,
+      );
     for (qw/Id Status SubmittedAt/) {
         my $method = lc $_;
         $self->$method( decode_entities( $resp->{ChangeInfo}{$_} ) );
