@@ -3,7 +3,7 @@ use warnings;
 
 package Net::Amazon::Route53::HostedZone;
 BEGIN {
-  $Net::Amazon::Route53::HostedZone::VERSION = '0.110310';
+  $Net::Amazon::Route53::HostedZone::VERSION = '0.111300';
 }
 use Mouse;
 use HTML::Entities;
@@ -51,10 +51,11 @@ Any Comment given when the zone is created
 
 =cut
 
-has 'id'              => ( is => 'rw', isa => 'Str', required => 1, default => '' );
-has 'name'            => ( is => 'rw', isa => 'Str', required => 1, default => '' );
-has 'callerreference' => ( is => 'rw', isa => 'Str', required => 1, default => '' );
-has 'comment'         => ( is => 'rw', isa => 'Str', required => 1, default => '' );
+has 'id'   => ( is => 'rw', isa => 'Str', required => 1, default => '' );
+has 'name' => ( is => 'rw', isa => 'Str', required => 1, default => '' );
+has 'callerreference' =>
+  ( is => 'rw', isa => 'Str', required => 1, default => '' );
+has 'comment' => ( is => 'rw', isa => 'Str', required => 1, default => '' );
 
 =head3 nameservers
 
@@ -68,10 +69,11 @@ has 'nameservers' => (
     lazy    => 1,
     default => sub {
         my $self = shift;
-        my $resp =
-          $self->route53->request( 'get', 'https://route53.amazonaws.com/2010-10-01/' . $self->id );
+        my $resp = $self->route53->request( 'get',
+            'https://route53.amazonaws.com/2010-10-01/' . $self->id );
         my @nameservers =
-          map { decode_entities($_) } @{ $resp->{DelegationSet}{NameServers}{NameServer} };
+          map { decode_entities($_) }
+          @{ $resp->{DelegationSet}{NameServers}{NameServer} };
         \@nameservers;
     }
 );
@@ -90,7 +92,9 @@ has 'resource_record_sets' => (
     default => sub {
         my $self = shift;
         my $resp = $self->route53->request( 'get',
-            'https://route53.amazonaws.com/2010-10-01/' . $self->id . '/rrset' );
+                'https://route53.amazonaws.com/2010-10-01/'
+              . $self->id
+              . '/rrset' );
         my @resource_record_sets;
         for my $res ( @{ $resp->{ResourceRecordSets}{ResourceRecordSet} } ) {
             push @resource_record_sets,
@@ -133,7 +137,8 @@ sub create {
     my $self = shift;
     my $wait = shift;
     $wait = 0 if !defined $wait;
-    $self->name =~ /\.$/ or die "Zone name needs to end in a dot, to be created\n";
+    $self->name =~ /\.$/
+      or die "Zone name needs to end in a dot, to be created\n";
     my $request_xml_str = <<'ENDXML';
 <?xml version="1.0" encoding="UTF-8"?>
 <CreateHostedZoneRequest xmlns="https://route53.amazonaws.com/doc/2010-10-01/">
@@ -144,8 +149,9 @@ sub create {
     </HostedZoneConfig>
 </CreateHostedZoneRequest>
 ENDXML
-    my $request_xml =
-      sprintf( $request_xml_str, map { $_ } $self->name, $self->callerreference, $self->comment );
+    my $request_xml = sprintf( $request_xml_str,
+        map { $_ } $self->name,
+        $self->callerreference, $self->comment );
     my $resp = $self->route53->request(
         'post',
         'https://route53.amazonaws.com/2010-10-01/hostedzone',
@@ -155,7 +161,10 @@ ENDXML
     $self->id( $resp->{HostedZone}{Id} );
     my $change = Net::Amazon::Route53::Change->new(
         route53 => $self->route53,
-        ( map { lc($_) => decode_entities( $resp->{ChangeInfo}{$_} ) } qw/Id Status SubmittedAt/ ),
+        (
+            map { lc($_) => decode_entities( $resp->{ChangeInfo}{$_} ) }
+              qw/Id Status SubmittedAt/
+        ),
     );
     $change->refresh();
     return $change if !$wait;
@@ -185,10 +194,15 @@ sub delete {
     my $wait = shift;
     $wait = 0 if !defined $wait;
     my $resp =
-      $self->route53->request( 'delete', 'https://route53.amazonaws.com/2010-10-01/' . $self->id, );
+      $self->route53->request( 'delete',
+        'https://route53.amazonaws.com/2010-10-01/' . $self->id,
+      );
     my $change = Net::Amazon::Route53::Change->new(
         route53 => $self->route53,
-        ( map { lc($_) => decode_entities( $resp->{ChangeInfo}{$_} ) } qw/Id Status SubmittedAt/ ),
+        (
+            map { lc($_) => decode_entities( $resp->{ChangeInfo}{$_} ) }
+              qw/Id Status SubmittedAt/
+        ),
     );
     $change->refresh();
     return $change if !$wait;
