@@ -3,7 +3,7 @@ use warnings;
 
 package Net::Amazon::Route53::ResourceRecordSet;
 BEGIN {
-  $Net::Amazon::Route53::ResourceRecordSet::VERSION = '0.110310';
+  $Net::Amazon::Route53::ResourceRecordSet::VERSION = '0.111300';
 }
 use Mouse;
 use XML::Bare;
@@ -31,8 +31,9 @@ The L<Net::Amazon::Route53::HostedZone> object this hosted zone refers to
 
 =cut
 
-has 'route53'    => ( is => 'rw', isa => 'Net::Amazon::Route53',             required => 1, );
-has 'hostedzone' => ( is => 'rw', isa => 'Net::Amazon::Route53::HostedZone', required => 1 );
+has 'route53' => ( is => 'rw', isa => 'Net::Amazon::Route53', required => 1, );
+has 'hostedzone' =>
+  ( is => 'rw', isa => 'Net::Amazon::Route53::HostedZone', required => 1 );
 
 =head3 name
 
@@ -52,10 +53,11 @@ The values associated with this resource record.
 
 =cut
 
-has 'name'   => ( is => 'rw', isa => 'Str',      required => 1 );
-has 'ttl'    => ( is => 'rw', isa => 'Int',      required => 1 );
-has 'type'   => ( is => 'rw', isa => 'Str',      required => 1 );
-has 'values' => ( is => 'rw', isa => 'ArrayRef', required => 1, default => sub { [] } );
+has 'name' => ( is => 'rw', isa => 'Str', required => 1 );
+has 'ttl'  => ( is => 'rw', isa => 'Int', required => 1 );
+has 'type' => ( is => 'rw', isa => 'Str', required => 1 );
+has 'values' =>
+  ( is => 'rw', isa => 'ArrayRef', required => 1, default => sub { [] } );
 
 =head2 METHODS
 
@@ -80,7 +82,8 @@ sub create {
     my $self = shift;
     my $wait = shift;
     $wait = 0 if !defined $wait;
-    $self->name =~ /\.$/ or die "Zone name needs to end in a dot, to be created\n";
+    $self->name =~ /\.$/
+      or die "Zone name needs to end in a dot, to be created\n";
     my $request_xml_str = <<'ENDXML';
 <?xml version="1.0" encoding="UTF-8"?>
 <ChangeResourceRecordSetsRequest xmlns="https://route53.amazonaws.com/doc/2010-10-01/">
@@ -94,9 +97,7 @@ sub create {
                <Type>%s</Type>
                <TTL>%s</TTL>
                <ResourceRecords>
-                  <ResourceRecord>
-                    %s
-                  </ResourceRecord>
+                  %s
                </ResourceRecords>
             </ResourceRecordSet>
          </Change>
@@ -104,18 +105,30 @@ sub create {
    </ChangeBatch>
 </ChangeResourceRecordSetsRequest>
 ENDXML
-    my $request_xml = sprintf( $request_xml_str,
+    my $request_xml = sprintf(
+        $request_xml_str,
         map { $_ } $self->type,
-        $self->name, $self->name, $self->type, $self->ttl,
-        join( "\n", map { "<Value>$_</Value>" } @{ $self->values } ) );
+        $self->name,
+        $self->name,
+        $self->type,
+        $self->ttl,
+        join( "\n",
+            map { "<ResourceRecord><Value>$_</Value></ResourceRecord>" }
+              @{ $self->values } )
+    );
     my $resp = $self->route53->request(
         'post',
-        'https://route53.amazonaws.com/2010-10-01/' . $self->hostedzone->id . '/rrset',
+        'https://route53.amazonaws.com/2010-10-01/'
+          . $self->hostedzone->id
+          . '/rrset',
         Content => $request_xml
     );
     my $change = Net::Amazon::Route53::Change->new(
         route53 => $self->route53,
-        ( map { lc($_) => decode_entities( $resp->{ChangeInfo}{$_} ) } qw/Id Status SubmittedAt/ ),
+        (
+            map { lc($_) => decode_entities( $resp->{ChangeInfo}{$_} ) }
+              qw/Id Status SubmittedAt/
+        ),
     );
     $change->refresh();
     return $change if !$wait;
@@ -162,9 +175,7 @@ sub delete {
                <Type>%s</Type>
                <TTL>%s</TTL>
                <ResourceRecords>
-                  <ResourceRecord>
-                    %s
-                  </ResourceRecord>
+                  %s
                </ResourceRecords>
             </ResourceRecordSet>
          </Change>
@@ -172,17 +183,32 @@ sub delete {
    </ChangeBatch>
 </ChangeResourceRecordSetsRequest>
 ENDXML
-    my $request_xml = sprintf( $request_xml_str,
-        ( map { $_ } ( $self->type, $self->name, $self->name, $self->type, $self->ttl ) ),
-        join( "\n", map { "<Value>" . $_ . "</Value>" } @{ $self->values } ) );
+    my $request_xml = sprintf(
+        $request_xml_str,
+        (
+            map { $_ } (
+                $self->type, $self->name, $self->name, $self->type, $self->ttl
+            )
+        ),
+        join(
+            "\n",
+            map { "<ResourceRecord><Value>" . $_ . "</Value></ResourceRecord>" }
+              @{ $self->values }
+        )
+    );
     my $resp = $self->route53->request(
         'post',
-        'https://route53.amazonaws.com/2010-10-01/' . $self->hostedzone->id . '/rrset',
+        'https://route53.amazonaws.com/2010-10-01/'
+          . $self->hostedzone->id
+          . '/rrset',
         Content => $request_xml
     );
     my $change = Net::Amazon::Route53::Change->new(
         route53 => $self->route53,
-        ( map { lc($_) => decode_entities( $resp->{ChangeInfo}{$_} ) } qw/Id Status SubmittedAt/ ),
+        (
+            map { lc($_) => decode_entities( $resp->{ChangeInfo}{$_} ) }
+              qw/Id Status SubmittedAt/
+        ),
     );
     $change->refresh();
     return $change if !$wait;
